@@ -27,10 +27,10 @@ a conversion function similar to for degrees Celsius.
 
 = References
 
-1. #note1# http://physics.nist.gov/Pubs/SP811/
-2. #note2# http://www.iau.org/science/publications/proceedings_rules/units/
-3. #note3# http://en.m.wikipedia.org/wiki/Pressure
-4. #note4# http://en.m.wikipedia.org/wiki/Torr
+1. #note1# https://www.nist.gov/pml/special-publication-811
+2. #note2# https://www.iau.org/publications/proceedings_rules/units/
+3. #note3# https://en.wikipedia.org/wiki/Pressure
+4. #note4# https://en.wikipedia.org/wiki/Torr
 
 -}
 
@@ -56,7 +56,7 @@ module Numeric.Units.Dimensional.NonSI
   usSurveyFoot, usSurveyInch, usSurveyMil, usSurveyYard, usSurveyMile, usSurveyAcre,
   -- * Years
   -- $year
-  year, century,
+  year, decade, century, millennium,
   -- * Pressure Units
   -- $pressure-units
   bar, atmosphere, technicalAtmosphere, mmHg, inHg, inHg_UCUM, inHg_NIST, torr,
@@ -99,7 +99,7 @@ import qualified Prelude
 From Table 7, units accepted for use with the SI whose values in SI units are
 obtained experimentally.
 
-When <#note1 [1]> was published the electron volt had a standard combined
+When <#note1 [1]> was published, the electron volt had a standard combined
 uncertainity of 0.00000049e-19 J and the unified atomic mass unit
 had a combined uncertainty of 0.0000010e-27 kg.
 
@@ -119,7 +119,7 @@ dalton = mkUnitR (ucumMetric "u" "Da" "Dalton") 1 $ unifiedAtomicMassUnit
 
 -- | One percent is one hundrendth.
 --
--- The dimensionless number 0.01 , represented by the symbol %, is commonly used as a dimensionless unit.
+-- The dimensionless number 0.01, represented by the symbol %, is commonly used as a dimensionless unit.
 --
 -- See section 7.10.2 of the <#note1 [1]> for further information.
 --
@@ -468,7 +468,7 @@ nauticalMile = mkUnitZ (ucum "[nmi_i]" "NM" "nautical mile") 1852 $ meter
 knot :: (Fractional a) => Unit 'NonMetric DVelocity a
 knot = mkUnitQ (ucum "[kt_i]" "kt" "knot") 1 $ nauticalMile / hour
 
--- | One revolution is an angle equal to 2 pi radians; a full circle.
+-- | One revolution is an angle equal to 2*pi radians; a full circle.
 --
 -- See <https://en.wikipedia.org/wiki/Turn_%28geometry%29 here> for further information.
 --
@@ -510,15 +510,17 @@ btu = mkUnitQ (ucum "[Btu_IT]" "btu" "British thermal unit") 1055.05585262 $ jou
 The IAU recommends <#note2 [2]> that:
 
   Although there are several different kinds of year (as there are
-  several kinds of day), it is best to regard a year as a julian
-  year of 365.25 days (31.5576 Ms) unless otherwise specified.
+  several kinds of day), it is best to regard a year as a Julian
+  year of 365.25 days (31557600 s) unless otherwise specified.
 
 -}
 
--- | One mean Julian year is a unit of measurement of time defined as exactly 365.25 days of 86 400 'second's each.
+-- | One Julian year is a unit of measurement of time defined as exactly 365.25 days of 86 400 'second's each.
 --
 -- See <https://en.wikipedia.org/wiki/Julian_year_%28astronomy%29 here> for further information.
 --
+-- prop> 1 *~ year === 365.25 *~ day
+--
 -- >>> 1 *~ year
 -- 3.15576e7 s
 --
@@ -527,7 +529,23 @@ The IAU recommends <#note2 [2]> that:
 year :: Num a => Unit 'NonMetric DTime a
 year = mkUnitZ (ucum "a_j" "a" "mean Julian year") 31557600 $ second
 
--- | One mean Julian century is one hundred mean Julian 'year's.
+-- | One Julian decade is ten Julian 'year's.
+--
+-- prop> 1 *~ decade === 10 *~ year
+--
+-- >>> 1 *~ decade
+-- 3.15576e8 s
+--
+-- >>> 1 *~ decade :: Time Rational
+-- 315576000 % 1 s
+decade :: Num a => Unit 'NonMetric DTime a
+decade = mkUnitZ (dimensionalAtom "d_j" "dec" "mean Julian decade") 10 $ year
+
+-- | One Julian century is one hundred Julian 'year's, or 35 525 'day's of 86 400 'second's each.
+--
+-- prop> 1 *~ century === 100 *~ year
+--
+-- prop> 1 *~ century === 36525 *~ day
 --
 -- >>> 1 *~ century
 -- 3.15576e9 s
@@ -537,6 +555,18 @@ year = mkUnitZ (ucum "a_j" "a" "mean Julian year") 31557600 $ second
 century :: Num a => Unit 'NonMetric DTime a
 century = mkUnitZ (dimensionalAtom "c_j" "cen" "mean Julian century") 100 $ year
 
+-- | One Julian millennium is one thousand Julian 'year's.
+--
+-- prop> 1 *~ millennium === 1000 *~ year
+--
+-- >>> 1 *~ millennium
+-- 3.15576e10 s
+--
+-- >>> 1 *~ millennium :: Time Rational
+-- 31557600000 % 1 s
+millennium :: Num a => Unit 'NonMetric DTime a
+millennium = mkUnitZ (dimensionalAtom "m_j" "mil" "mean Julian millennium") 1000 $ year
+
 {- $pressure-units
 It seems that nearly every area of application has its own customary unit for measuring pressure.
 We include some of the common ones here. 'psi' was defined earlier.
@@ -726,7 +756,7 @@ degreeRankine :: (Fractional a) => Unit 'NonMetric DThermodynamicTemperature a
 degreeRankine = mkUnitQ (ucum "[degR]" "°R" "degree Rankine") 1 $ degreeFahrenheit
 
 {- $imperial-volumes
-Per http://en.wikipedia.org/wiki/Imperial_units and http://en.wikipedia.org/wiki/Cup_(unit)#Imperial_cup.
+Per https://en.wikipedia.org/wiki/Imperial_units and https://en.wikipedia.org/wiki/Cup_(unit)#Imperial_cup.
 -}
 
 -- | One imperial gallon is defined exactly in terms of the 'liter'
@@ -806,7 +836,7 @@ imperialFluidOunce :: (Fractional a) => Unit 'NonMetric DVolume a
 imperialFluidOunce = mkUnitQ (ucum "[foz_br]" "fl oz" "fluid ounce") (1 Prelude./ 20) $ imperialPint
 
 {- $us-customary-volumes
-Per http://www.nist.gov/pml/wmd/pubs/upload/2012-hb44-final.pdf page 452 and http://en.wikipedia.org/wiki/United_States_customary_units#Fluid_volume
+Per https://www.nist.gov/system/files/documents/2017/05/09/2012-hb44-final.pdf page 452 and https://en.wikipedia.org/wiki/United_States_customary_units#Fluid_volume
 Note that there exist rarely-used "dry" variants of units with overlapping names.
 -}
 
