@@ -20,11 +20,11 @@ The definitions in this module are grouped so that a type synonym
 for the dimensionality is defined first in terms of base dimension
 exponents. Then a type synonym for the corresponding quantity type
 is defined. If there are several quantity types with the same
-dimensionality type synonyms are provided for each quantity type.
+dimensionality, type synonyms are provided for each quantity type.
 
 = References
 
-1. #note1# http://physics.nist.gov/Pubs/SP811/
+1. #note1# https://www.nist.gov/pml/special-publication-811
 
 -}
 
@@ -373,7 +373,7 @@ type ThermalResistivity = Quantity DThermalResistivity
 
 {-
 
-Thermal conductance and resistance quantities after http://en.wikipedia.org/wiki/Thermal_conductivity#Definitions.
+Thermal conductance and resistance quantities after https://en.wikipedia.org/wiki/Thermal_conductivity#Definitions.
 
 -}
 
