@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE TypeSynonymInstances #-}
 
@@ -6,5 +7,11 @@ module Main (main) where
 import System.FilePath.Glob (glob)
 import Test.DocTest (doctest)
 
+#if MIN_VERSION_base(4,12,0)
+doctestFlags = ["-XNoStarIsType"]
+#else
+doctestFlags = []
+#endif
+
 main :: IO ()
-main = glob "src/**/*.hs" >>= doctest
+main = glob "src/**/*.hs" >>= (doctest . (doctestFlags++))
